==> libstpk-0.9.16.0.tar.gz: libstpk-0.9.16.0/demo/BAROVOR/tmp/fft_check2.f90 <==
module m_phase1

  implicit none

contains

  subroutine phase1( nx, ny, ival1, oval1, fval1, wnx, wny, spgix, spgiy )

  use Math_Const
  use ffts

  implicit none

  integer, intent(in) :: nx, ny
  real, dimension(nx,ny), intent(in) :: ival1
  real, dimension(nx,ny), intent(out) :: oval1
  real, dimension(nx,ny), intent(out) :: fval1
  integer, intent(in) :: wnx, wny
  integer, intent(in) :: spgix, spgiy

  integer, parameter :: ifft=5
  integer :: i, j
  real :: t1, t2, t3
  integer, dimension(ifft) :: pxfact, pyfact, pxsfact, pysfact
  complex, dimension(nx,ny) :: sp, spi
  complex, dimension(nx/spgix,ny/spgiy) :: cpval1, cpval2, fpval1, fpval2, sps1, sps2, spis1, spis2
  complex, allocatable, dimension(:,:) :: omegaxbr, omegaybr, omegaxbi, omegaybi
  complex, allocatable, dimension(:,:) :: omegaxnr, omegaynr, omegaxni, omegayni
  complex, allocatable, dimension(:,:) :: omegaxbrs, omegaybrs, omegaxbis, omegaybis
  complex, allocatable, dimension(:,:) :: omegaxnrs, omegaynrs, omegaxnis, omegaynis

  call rotate_array_f()
  call prim_calc( nx, pxfact(1:4), pxfact(5) )
  call prim_calc( ny, pyfact(1:4), pyfact(5) )
  call prim_calc( nx/spgix, pxsfact(1:4), pxsfact(5) )
  call prim_calc( ny/spgiy, pysfact(1:4), pysfact(5) )

  allocate(omegaxnr(0:nx-1,0:nx-1))
  allocate(omegaynr(0:ny-1,0:ny-1))
  allocate(omegaxni(0:nx-1,0:nx-1))
  allocate(omegayni(0:ny-1,0:ny-1))
  allocate(omegaxbr(0:pxfact(5)-1,0:pxfact(5)-1))
  allocate(omegaybr(0:pyfact(5)-1,0:pyfact(5)-1))
  allocate(omegaxbi(0:pxfact(5)-1,0:pxfact(5)-1))
  allocate(omegaybi(0:pyfact(5)-1,0:pyfact(5)-1))
  allocate(omegaxnrs(0:nx/spgix-1,0:nx/spgix-1))
  allocate(omegaynrs(0:ny/spgiy-1,0:ny/spgiy-1))
  allocate(omegaxnis(0:nx/spgix-1,0:nx/spgix-1))
  allocate(omegaynis(0:ny/spgiy-1,0:ny/spgiy-1))
  allocate(omegaxbrs(0:pxsfact(5)-1,0:pxsfact(5)-1))
  allocate(omegaybrs(0:pysfact(5)-1,0:pysfact(5)-1))
  allocate(omegaxbis(0:pxsfact(5)-1,0:pxsfact(5)-1))
  allocate(omegaybis(0:pysfact(5)-1,0:pysfact(5)-1))

  call rotate_calc( nx, 'r', pxfact,  &
  &               omegaxbr(0:pxfact(5)-1,0:pxfact(5)-1),  &
  &               omegaxnr(0:nx-1,0:nx-1) )
  call rotate_calc( nx, 'i', pxfact,  &
  &               omegaxbi(0:pxfact(5)-1,0:pxfact(5)-1),  &
  &               omegaxni(0:nx-1,0:nx-1) )
  call rotate_calc( ny, 'r', pyfact,  &
  &               omegaybr(0:pyfact(5)-1,0:pyfact(5)-1),  &
  &               omegaynr(0:ny-1,0:ny-1) )
  call rotate_calc( ny, 'i', pyfact,  &
  &               omegaybi(0:pyfact(5)-1,0:pyfact(5)-1),  &
  &               omegayni(0:ny-1,0:ny-1) )

  call rotate_calc( nx/spgix, 'r', pxsfact,  &
  &               omegaxbrs(0:pxsfact(5)-1,0:pxsfact(5)-1),  &
  &               omegaxnrs(0:nx/spgix-1,0:nx/spgix-1) )
  call rotate_calc( nx/spgix, 'i', pxsfact,  &
  &               omegaxbis(0:pxsfact(5)-1,0:pxsfact(5)-1),  &
  &               omegaxnis(0:nx/spgix-1,0:nx/spgix-1) )
  call rotate_calc( ny/spgiy, 'r', pysfact,  &
  &               omegaybrs(0:pysfact(5)-1,0:pysfact(5)-1),  &
  &               omegaynrs(0:ny/spgiy-1,0:ny/spgiy-1) )
  call rotate_calc( ny/spgiy, 'i', pysfact,  &
  &               omegaybis(0:pysfact(5)-1,0:pysfact(5)-1),  &
  &               omegaynis(0:ny/spgiy-1,0:ny/spgiy-1) )

  do j=1,ny/spgiy
     do i=1,nx/spgix
        cpval1(i,j)=ival1((i-1)*spgix+1,(j-1)*spgiy+1)
        fpval1(i,j)=cpval1(i,j)
     end do
  end do

  call cpu_time(t1)

  call ffttp_2d( nx/spgix, ny/spgiy,  &
  &              cpval1(1:nx/spgix,1:ny/spgiy),  &
  &              cpval2(1:nx/spgix,1:ny/spgiy),  &
  &              'r', 'o', prim_factx=pxsfact, prim_facty=pysfact,  &
  &              omegax_fix=omegaxbrs, omegaxn_fix=omegaxnrs,  &
  &              omegay_fix=omegaybrs, omegayn_fix=omegaynrs )

  call cpu_time(t2)

  write(*,*) "cpu_time is ", t2-t1, "[sec]."

  call ffttp_2d( nx/spgix, ny/spgiy,  &
  &              fpval1(1:nx/spgix,1:ny/spgiy),  &
  &              fpval2(1:nx/spgix,1:ny/spgiy),  &
  &              'r', 'o', prim_factx=pxsfact, prim_facty=pysfact,  &
  &              omegax_fix=omegaxbrs, omegaxn_fix=omegaxnrs,  &
  &              omegay_fix=omegaybrs, omegayn_fix=omegaynrs )

  sp=0.0

  sp(1,1)=cpval2(1,1)
  sp(nx,ny)=cpval2(nx/spgix,ny/spgiy)

  do j=2,wny+1
     sp(1,j)=cpval2(1,j)
     sp(1,ny-j+2)=cpval2(1,ny/spgiy-j+2)
  end do

  do i=2,wnx+1
     sp(i,1)=cpval2(i,1)
     sp(nx-i+2,1)=cpval2(nx/spgix-i+2,1)
  end do

  do j=2,wny+1
     do i=2,wnx+1
        sp(i,j)=cpval2(i,j)
        sp(nx-i+2,ny-j+2)=cpval2(nx/spgix-i+2,ny/spgiy-j+2)
        sp(i,ny-j+2)=cpval2(i,ny/spgiy-j+2)
        sp(nx-i+2,j)=cpval2(nx/spgix-i+2,j)
     end do
  end do

  call ffttp_2d( nx, ny, sp(1:nx,1:ny), spi(1:nx,1:ny),  &
  &              'i', 'o', prim_factx=pxfact, prim_facty=pyfact,  &
  &              omegax_fix=omegaxbi, omegaxn_fix=omegaxni,  &
  &              omegay_fix=omegaybi, omegayn_fix=omegayni )

  call ffttp_2d( nx, ny, fpval2(1:nx,1:ny), fpval1(1:nx,1:ny),  &
  &              'i', 'o', prim_factx=pxfact, prim_facty=pyfact,  &
  &              omegax_fix=omegaxbi, omegaxn_fix=omegaxni,  &
  &              omegay_fix=omegaybi, omegayn_fix=omegayni )

  do j=1,ny
     do i=1,nx
        oval1(i,j)=real(spi(i,j))
        fval1(i,j)=real(fpval1(i,j))
     end do
  end do

  end subroutine phase1

end module m_phase1

program fft_check2

!-- fft_check2 Ʊ. 2 ʬۤ򥬥ʬۤˤ.

  use m_phase1
  use math_const
  use max_min

  implicit none

  integer, parameter :: nx=500, ny=500
  integer, parameter :: spgix=1, spgiy=1
  integer, parameter :: wnx=10, wny=5

  integer :: i, j, k, l, icounter, ip, jp
  integer :: ixmax, iymax
  real :: emax
  real :: x(nx), y(ny)
  real, allocatable, dimension(:,:) :: valp1
  real, allocatable, dimension(:) :: totsp1, totsp2
  real, dimension(nx,ny) :: ival1, oval0, oval1, oval2, fval1, error

     x=(/((real(i)/real(nx)),i=1,nx)/)
     y=(/((real(j)/real(ny)),j=1,ny)/)

     ival1=0.0

     do j=1,ny
        do i=1,nx
           do l=0,wny
              do k=0,wnx
                 ival1(i,j)=exp(-((real(i)-0.5*real(nx))**2  &
  &                              +(real(j)-0.5*real(ny))**2))
                 error(i,j)=abs(ival1(i,j))
              end do
           end do
        end do
     end do

!-- Normalize ival1

     call max_val_2d( ival1, ixmax, iymax, emax )
     do j=1,ny
        do i=1,nx
           ival1(i,j)=ival1(i,j)/emax
        end do
     end do

     call phase1( nx, ny, ival1, oval1, fval1, wnx, wny, spgix, spgiy )

     do j=1,ny
        do i=1,nx
           error(i,j)=abs(oval1(i,j)-ival1(i,j))
        end do
     end do

     call max_val_2d( error, ixmax, iymax, emax )

     write(*,'(a28)') "*********** Result **********"
     write(*,'(a12,1PE16.8)') "ERROR max : ", emax
     write(*,'(a12,1PE16.8)') "Input val : ", ival1(ixmax,iymax)
     write(*,'(a12,1PE16.8)') "Output val: ", oval1(ixmax,iymax)

     do j=1,ny
        do i=1,nx
           error(i,j)=abs(fval1(i,j)-ival1(i,j))
        end do
     end do

     call max_val_2d( error, ixmax, iymax, emax )

     write(*,'(a28)') "******* Result (full) ******"
     write(*,'(a12,1PE16.8)') "ERROR max : ", emax
     write(*,'(a12,1PE16.8)') "Input val : ", ival1(ixmax,iymax)
     write(*,'(a12,1PE16.8)') "Output val: ", fval1(ixmax,iymax)

end program fft_check2

==> libstpk-0.9.20.0.tar.gz: libstpk-0.9.20.0/demo/BAROVOR/tmp/fft_check2.f90 <==
module m_phase1

  implicit none

contains

  subroutine phase1( nx, ny, ival1, oval1, fval1, wnx, wny, spgix, spgiy )

  use Math_Const
  use ffts

  implicit none

  integer, intent(in) :: nx, ny
  real, dimension(nx,ny), intent(in) :: ival1
  real, dimension(nx,ny), intent(out) :: oval1
  real, dimension(nx,ny), intent(out) :: fval1
  integer, intent(in) :: wnx, wny
  integer, intent(in) :: spgix, spgiy

  integer, parameter :: ifft=5
  integer :: i, j
  real :: t1, t2, t3
  integer, dimension(ifft) :: pxfact, pyfact, pxsfact, pysfact
  complex, dimension(nx,ny) :: sp, spi
  complex, dimension(nx/spgix,ny/spgiy) :: cpval1, cpval2, fpval1, fpval2, sps1, sps2, spis1, spis2
  complex, allocatable, dimension(:,:) :: omegaxbr, omegaybr, omegaxbi, omegaybi
  complex, allocatable, dimension(:,:) :: omegaxnr, omegaynr, omegaxni, omegayni
  complex, allocatable, dimension(:,:) :: omegaxbrs, omegaybrs, omegaxbis, omegaybis
  complex, allocatable, dimension(:,:) :: omegaxnrs, omegaynrs, omegaxnis, omegaynis

  call rotate_array_f()
  call prim_calc( nx, pxfact(1:4), pxfact(5) )
  call prim_calc( ny, pyfact(1:4), pyfact(5) )
  call prim_calc( nx/spgix, pxsfact(1:4), pxsfact(5) )
  call prim_calc( ny/spgiy, pysfact(1:4), pysfact(5) )

  allocate(omegaxnr(0:nx-1,0:nx-1))
  allocate(omegaynr(0:ny-1,0:ny-1))
  allocate(omegaxni(0:nx-1,0:nx-1))
  allocate(omegayni(0:ny-1,0:ny-1))
  allocate(omegaxbr(0:pxfact(5)-1,0:pxfact(5)-1))
  allocate(omegaybr(0:pyfact(5)-1,0:pyfact(5)-1))
  allocate(omegaxbi(0:pxfact(5)-1,0:pxfact(5)-1))
  allocate(omegaybi(0:pyfact(5)-1,0:pyfact(5)-1))
  allocate(omegaxnrs(0:nx/spgix-1,0:nx/spgix-1))
  allocate(omegaynrs(0:ny/spgiy-1,0:ny/spgiy-1))
  allocate(omegaxnis(0:nx/spgix-1,0:nx/spgix-1))
  allocate(omegaynis(0:ny/spgiy-1,0:ny/spgiy-1))
  allocate(omegaxbrs(0:pxsfact(5)-1,0:pxsfact(5)-1))
  allocate(omegaybrs(0:pysfact(5)-1,0:pysfact(5)-1))
  allocate(omegaxbis(0:pxsfact(5)-1,0:pxsfact(5)-1))
  allocate(omegaybis(0:pysfact(5)-1,0:pysfact(5)-1))

  call rotate_calc( nx, 'r', pxfact,  &
  &               omegaxbr(0:pxfact(5)-1,0:pxfact(5)-1),  &
  &               omegaxnr(0:nx-1,0:nx-1) )
  call rotate_calc( nx, 'i', pxfact,  &
  &               omegaxbi(0:pxfact(5)-1,0:pxfact(5)-1),  &
  &               omegaxni(0:nx-1,0:nx-1) )
  call rotate_calc( ny, 'r', pyfact,  &
  &               omegaybr(0:pyfact(5)-1,0:pyfact(5)-1),  &
  &               omegaynr(0:ny-1,0:ny-1) )
  call rotate_calc( ny, 'i', pyfact,  &
  &               omegaybi(0:pyfact(5)-1,0:pyfact(5)-1),  &
  &               omegayni(0:ny-1,0:ny-1) )

  call rotate_calc( nx/spgix, 'r', pxsfact,  &
  &               omegaxbrs(0:pxsfact(5)-1,0:pxsfact(5)-1),  &
  &               omegaxnrs(0:nx/spgix-1,0:nx/spgix-1) )
  call rotate_calc( nx/spgix, 'i', pxsfact,  &
  &               omegaxbis(0:pxsfact(5)-1,0:pxsfact(5)-1),  &
  &               omegaxnis(0:nx/spgix-1,0:nx/spgix-1) )
  call rotate_calc( ny/spgiy, 'r', pysfact,  &
  &               omegaybrs(0:pysfact(5)-1,0:pysfact(5)-1),  &
  &               omegaynrs(0:ny/spgiy-1,0:ny/spgiy-1) )
  call rotate_calc( ny/spgiy, 'i', pysfact,  &
  &               omegaybis(0:pysfact(5)-1,0:pysfact(5)-1),  &
  &               omegaynis(0:ny/spgiy-1,0:ny/spgiy-1) )

  do j=1,ny/spgiy
     do i=1,nx/spgix
        cpval1(i,j)=ival1((i-1)*spgix+1,(j-1)*spgiy+1)
        fpval1(i,j)=cpval1(i,j)
     end do
  end do

  call cpu_time(t1)

  call ffttp_2d( nx/spgix, ny/spgiy,  &
  &              cpval1(1:nx/spgix,1:ny/spgiy),  &
  &              cpval2(1:nx/spgix,1:ny/spgiy),  &
  &              'r', 'o', prim_factx=pxsfact, prim_facty=pysfact,  &
  &              omegax_fix=omegaxbrs, omegaxn_fix=omegaxnrs,  &
  &              omegay_fix=omegaybrs, omegayn_fix=omegaynrs )

  call cpu_time(t2)

  write(*,*) "cpu_time is ", t2-t1, "[sec]."

  call ffttp_2d( nx/spgix, ny/spgiy,  &
  &              fpval1(1:nx/spgix,1:ny/spgiy),  &
  &              fpval2(1:nx/spgix,1:ny/spgiy),  &
  &              'r', 'o', prim_factx=pxsfact, prim_facty=pysfact,  &
  &              omegax_fix=omegaxbrs, omegaxn_fix=omegaxnrs,  &
  &              omegay_fix=omegaybrs, omegayn_fix=omegaynrs )

  sp=0.0

  sp(1,1)=cpval2(1,1)

  do j=2,wny+1
     sp(1,j)=cpval2(1,j)
     sp(1,ny-j+2)=cpval2(1,ny-j+2)
  end do

  do i=2,wnx+1
     sp(i,1)=cpval2(i,1)
     sp(nx-i+2,1)=cpval2(nx-i+2,1)
  end do

  do j=2,wny+1
     do i=2,wnx+1
        sp(i,j)=cpval2(i,j)
        sp(i,ny-j+2)=cpval2(i,ny-j+2)
        sp(nx-i+2,j)=cpval2(nx-i+2,j)
        sp(nx-i+2,ny-j+2)=cpval2(nx-i+2,ny-j+2)
     end do
  end do

  call ffttp_2d( nx, ny, sp(1:nx,1:ny), spi(1:nx,1:ny),  &
  &              'i', 'o', prim_factx=pxfact, prim_facty=pyfact,  &
  &              omegax_fix=omegaxbi, omegaxn_fix=omegaxni,  &
  &              omegay_fix=omegaybi, omegayn_fix=omegayni )

  call ffttp_2d( nx, ny, fpval2(1:nx,1:ny), fpval1(1:nx,1:ny),  &
  &              'i', 'o', prim_factx=pxfact, prim_facty=pyfact,  &
  &              omegax_fix=omegaxbi, omegaxn_fix=omegaxni,  &
  &              omegay_fix=omegaybi, omegayn_fix=omegayni )

  do j=1,ny
     do i=1,nx
        oval1(i,j)=real(spi(i,j))
        fval1(i,j)=real(fpval1(i,j))
     end do
  end do

  end subroutine phase1

end module m_phase1

program fft_check2

!-- fft_check2 Ʊ. 2 ʬۤ򥬥ʬۤˤ.

  use m_phase1
  use math_const
  use max_min

  implicit none

  integer, parameter :: nx=500, ny=500
  integer, parameter :: spgix=1, spgiy=1
  integer, parameter :: wnx=10, wny=5

  integer :: i, j, k, l, icounter, ip, jp
  integer :: ixmax, iymax
  real :: emax
  real :: x(nx), y(ny)
  real, allocatable, dimension(:,:) :: valp1
  real, allocatable, dimension(:) :: totsp1, totsp2
  real, dimension(nx,ny) :: ival1, oval0, oval1, oval2, fval1, error

     x=(/((real(i)/real(nx)),i=1,nx)/)
     y=(/((real(j)/real(ny)),j=1,ny)/)

     ival1=0.0

     do j=1,ny
        do i=1,nx
           do l=0,wny
              do k=0,wnx
                 ival1(i,j)=exp(-((real(i)-0.5*real(nx))**2  &
  &                              +(real(j)-0.5*real(ny))**2))
                 error(i,j)=abs(ival1(i,j))
              end do
           end do
        end do
     end do

!-- Normalize ival1

     call max_val_2d( ival1, ixmax, iymax, emax )
     do j=1,ny
        do i=1,nx
           ival1(i,j)=ival1(i,j)/emax
        end do
     end do

     call phase1( nx, ny, ival1, oval1, fval1, wnx, wny, spgix, spgiy )

     do j=1,ny
        do i=1,nx
           error(i,j)=abs(oval1(i,j)-ival1(i,j))
        end do
     end do

     call max_val_2d( error, ixmax, iymax, emax )

     write(*,'(a28)') "*********** Result **********"
     write(*,'(a12,1PE16.8)') "ERROR max : ", emax
     write(*,'(a12,1PE16.8)') "Input val : ", ival1(ixmax,iymax)
     write(*,'(a12,1PE16.8)') "Output val: ", oval1(ixmax,iymax)

     do j=1,ny
        do i=1,nx
           error(i,j)=abs(fval1(i,j)-ival1(i,j))
        end do
     end do

     call max_val_2d( error, ixmax, iymax, emax )

     write(*,'(a28)') "******* Result (full) ******"
     write(*,'(a12,1PE16.8)') "ERROR max : ", emax
     write(*,'(a12,1PE16.8)') "Input val : ", ival1(ixmax,iymax)
     write(*,'(a12,1PE16.8)') "Output val: ", fval1(ixmax,iymax)

end program fft_check2
